from .core.coordinate import Coordinate
from .core.lines import Line, Segment
from .core import operations
